@@ -6,7 +6,6 @@
 
 #include "iokitstorageaccess.h"
 
-
 #include <CoreFoundation/CoreFoundation.h>
 #include <DiskArbitration/DiskArbitration.h>
 
@@ -16,16 +15,14 @@ IOKitStorageAccess::IOKitStorageAccess(IOKitDevice *device)
     : DeviceInterface(device)
     , daDict(new DADictionary(device))
 {
-    connect(device, SIGNAL(propertyChanged(QMap<QString,int>)),
-            this, SLOT(onPropertyChanged(QMap<QString,int>)));
+    connect(device, SIGNAL(propertyChanged(QMap<QString, int>)), this, SLOT(onPropertyChanged(QMap<QString, int>)));
 }
 
 IOKitStorageAccess::IOKitStorageAccess(const IOKitDevice *device)
     : DeviceInterface(device)
     , daDict(new DADictionary(device))
 {
-    connect(device, SIGNAL(propertyChanged(QMap<QString,int>)),
-            this, SLOT(onPropertyChanged(QMap<QString,int>)));
+    connect(device, SIGNAL(propertyChanged(QMap<QString, int>)), this, SLOT(onPropertyChanged(QMap<QString, int>)));
 }
 
 IOKitStorageAccess::~IOKitStorageAccess()
@@ -44,7 +41,7 @@ QString IOKitStorageAccess::filePath() const
 {
     // mount points can change (but can they between invocations of filePath()?)
     QString mountPoint;
-    if (const CFURLRef urlRef  = daDict->cfUrLRefForKey(kDADiskDescriptionVolumePathKey)) {
+    if (const CFURLRef urlRef = daDict->cfUrLRefForKey(kDADiskDescriptionVolumePathKey)) {
         const CFStringRef mpRef = CFURLCopyFileSystemPath(urlRef, kCFURLPOSIXPathStyle);
         mountPoint = QString::fromCFString(mpRef);
         CFRelease(mpRef);
@@ -53,7 +50,7 @@ QString IOKitStorageAccess::filePath() const
         const QString isMountedKey = QStringLiteral("isMounted");
         const QVariant wasMounted = m_device->property(isMountedKey);
         if (wasMounted.isValid() && wasMounted.toBool() != isMounted) {
-            IOKitStorageAccess(m_device).onPropertyChanged(QMap<QString,int>{{isMountedKey,isMounted}});
+            IOKitStorageAccess(m_device).onPropertyChanged(QMap<QString, int>{{isMountedKey, isMounted}});
         }
         m_device->setProperty("isMounted", QVariant(isMounted));
     }
@@ -72,6 +69,12 @@ bool IOKitStorageAccess::isIgnored() const
     return isIgnored.isValid() && isIgnored.toBool();
 }
 
+bool IOKitStorageAccess::isEncrypted() const
+{
+    // TODO: Implementation left for IOKit developer
+    return false;
+}
+
 bool IOKitStorageAccess::setup()
 {
     // TODO?
@@ -86,10 +89,9 @@ bool IOKitStorageAccess::teardown()
 
 void IOKitStorageAccess::onPropertyChanged(const QMap<QString, int> &changes)
 {
-    Q_FOREACH (const QString &property, changes.keys()) {
-        if (property == QStringLiteral("isMounted")) {
-            emit accessibilityChanged(m_device->property(QStringLiteral("isMounted")).toBool(), m_device->udi());
+    for (auto it = changes.cbegin(); it != changes.cend(); ++it) {
+        if (it.key() == QLatin1String("isMounted")) {
+            Q_EMIT accessibilityChanged(m_device->property(QStringLiteral("isMounted")).toBool(), m_device->udi());
         }
     }
 }
-
